Learn R Programming

jgsbook (version 1.0.6)

KInormal_a: compute confidence intervall for mean of normal distributed data

Description

returns borders and length of confidence intervall for mean of normal distributed data

Usage

KInormal_a(xquer, s, n, alpha)

Value

confidence intervall

Arguments

xquer

mean of obeserved data

s

standard deviation of observed data

n

number of observations

alpha

error niveau

Examples

Run this code
KInormal_a(400, 20, 100, 0.05)

Run the code above in your browser using DataLab